@@ -17,6 +17,8 @@
 
 package org.apache.inlong.agent.plugin;
 
+import org.apache.inlong.agent.conf.JobProfile;
+
 /**
  * Sink data to remote data center
  */
@@ -29,10 +31,14 @@ public interface Sink extends Stage {
      */
     void write(Message message);
 
-
     /**
      * set source file name where the message is generated
      * @param sourceFileName
      */
     void setSourceFile(String sourceFileName);
+
+    /**
+     * every sink should include a message filter to filter out tid
+     */
+    MessageFilter initMessageFilter(JobProfile jobConf);
 }
