@@ -30,7 +30,7 @@ CREATE TABLE `agent_heartbeat_log`
     `modify_time`   timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time',
     PRIMARY KEY (`ip`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = utf8 COMMENT ='Agent heartbeat information table';
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Agent heartbeat information table';
 
 -- ----------------------------
 -- Table structure for agent_sys_conf
@@ -65,7 +65,7 @@ CREATE TABLE `agent_sys_conf`
     `is_calMD5`                     tinyint(2)           DEFAULT NULL COMMENT 'Do you want to calculate the cumulative md5 of read characters',
     PRIMARY KEY (`ip`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = utf8 COMMENT ='Agent system configuration table';
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Agent system configuration table';
 
 -- ----------------------------
 -- Table structure for business
@@ -97,7 +97,6 @@ CREATE TABLE `business`
     PRIMARY KEY (`id`),
     UNIQUE KEY `unique_business` (`business_identifier`, `is_deleted`, `modify_time`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 16
   DEFAULT CHARSET = utf8mb4 COMMENT ='Business table';
 
 -- ----------------------------
@@ -228,7 +227,6 @@ CREATE TABLE `consumption`
     PRIMARY KEY (`id`),
     UNIQUE KEY `consumer_group_id_is_deleted_uindex` (`consumer_group_id`, `is_deleted`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 6
   DEFAULT CHARSET = utf8mb4 COMMENT ='Data consumption configuration table';
 
 -- ----------------------------
@@ -272,7 +270,6 @@ CREATE TABLE `data_schema`
     PRIMARY KEY (`id`),
     UNIQUE KEY `name` (`name`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 10
   DEFAULT CHARSET = utf8mb4 COMMENT ='Data format table';
 
 -- create default data schema
@@ -296,7 +293,7 @@ CREATE TABLE `data_source_cmd_config`
     PRIMARY KEY (`id`),
     KEY `index_1` (`task_id`, `bSend`, `specified_data_time`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = utf8;
+  DEFAULT CHARSET = utf8mb4;
 
 -- ----------------------------
 -- Table structure for data_stream
@@ -328,7 +325,6 @@ CREATE TABLE `data_stream`
     PRIMARY KEY (`id`),
     UNIQUE KEY `unique_data_stream` (`data_stream_identifier`, `business_identifier`, `is_deleted`, `modify_time`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 28
   DEFAULT CHARSET = utf8mb4 COMMENT ='Data stream table';
 
 -- ----------------------------
@@ -373,7 +369,6 @@ CREATE TABLE `data_stream_field`
     PRIMARY KEY (`id`),
     KEY `index_stream_id` (`data_stream_identifier`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 39
   DEFAULT CHARSET = utf8mb4 COMMENT ='File/DB data source field table';
 
 -- ----------------------------
@@ -399,7 +394,6 @@ CREATE TABLE `operation_log`
     `err_msg`             text COMMENT 'Error message',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 289
   DEFAULT CHARSET = utf8mb4;
 
 -- ----------------------------
@@ -495,7 +489,6 @@ CREATE TABLE `source_file_basic`
     `temp_view`              json                  DEFAULT NULL COMMENT 'temp view',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 9
   DEFAULT CHARSET = utf8mb4 COMMENT ='basic configuration of file data source';
 
 -- ----------------------------
@@ -526,7 +519,6 @@ CREATE TABLE `source_file_detail`
     `temp_view`              json                  DEFAULT NULL COMMENT 'Temporary view, used to save unsubmitted and unapproved intermediate data after modification',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 3
   DEFAULT CHARSET = utf8mb4 COMMENT ='Detailed table of file data source';
 
 -- ----------------------------
@@ -545,7 +537,6 @@ CREATE TABLE `storage_ext`
     PRIMARY KEY (`id`),
     KEY `index_bid` (`storage_id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 11
   DEFAULT CHARSET = utf8mb4 COMMENT ='Data storage extension table';
 
 -- ----------------------------
@@ -584,7 +575,6 @@ CREATE TABLE `storage_hive`
     `opt_log`                varchar(5000)         DEFAULT NULL COMMENT 'Background operation log',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 21
   DEFAULT CHARSET = utf8mb4 COMMENT ='Data is stored in Hive configuration table';
 
 -- ----------------------------
@@ -610,7 +600,6 @@ CREATE TABLE `storage_hive_field`
     PRIMARY KEY (`id`),
     KEY `index_storage_id` (`storage_id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 34
   DEFAULT CHARSET = utf8mb4 COMMENT ='Data stored in Hive field';
 
 -- ----------------------------
@@ -632,7 +621,7 @@ CREATE TABLE `task`
     `update_by`   varchar(0)    DEFAULT NULL COMMENT 'last modified person',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = latin1 COMMENT ='Task information table';
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Task information table';
 
 -- ----------------------------
 -- Table structure for task_def
@@ -652,7 +641,7 @@ CREATE TABLE `task_def`
     `delivery_id`     bigint(20)   DEFAULT NULL COMMENT 'Task push method',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = latin1 COMMENT ='Task definition under workflow';
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Task definition under workflow';
 
 -- ----------------------------
 -- Table structure for taskflow
@@ -670,7 +659,7 @@ CREATE TABLE `taskflow`
     `event`           varchar(255) DEFAULT NULL COMMENT 'trigger event',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = latin1 COMMENT ='Task flow instance';
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Task flow instance';
 
 -- ----------------------------
 -- Table structure for taskflow_def
@@ -687,7 +676,7 @@ CREATE TABLE `taskflow_def`
     `trigger_event` varchar(255) DEFAULT NULL COMMENT 'trigger event',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  DEFAULT CHARSET = latin1 COMMENT ='Task flow definition';
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Task flow definition';
 
 -- ----------------------------
 -- Table structure for user
@@ -707,7 +696,6 @@ CREATE TABLE `user`
     PRIMARY KEY (`id`),
     UNIQUE KEY `user_name_uindex` (`name`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 25
   DEFAULT CHARSET = utf8mb4 COMMENT ='User table';
 
 -- create default admin user, username is 'admin', password is 'inlong'
@@ -754,7 +742,6 @@ CREATE TABLE `wf_approver`
     PRIMARY KEY (`id`),
     KEY `process_name_task_name_index` (`process_name`, `task_name`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 5
   DEFAULT CHARSET = utf8mb4 COMMENT ='Workflow approver table';
 
 -- create default approver for new consumption and new business
@@ -791,7 +778,6 @@ CREATE TABLE `wf_event_log`
     `exception`            text COMMENT 'Exception information',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 5170
   DEFAULT CHARSET = utf8mb4 COMMENT ='Workflow event log table';
 
 -- ----------------------------
@@ -815,7 +801,6 @@ CREATE TABLE `wf_process_instance`
     `hidden`       tinyint(1)   NOT NULL DEFAULT '0' COMMENT 'Is it hidden',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 197
   DEFAULT CHARSET = utf8mb4 COMMENT ='Process instance';
 
 -- ----------------------------
@@ -842,7 +827,222 @@ CREATE TABLE `wf_task_instance`
     `ext`                  text COMMENT 'Extended information-json',
     PRIMARY KEY (`id`)
 ) ENGINE = InnoDB
-  AUTO_INCREMENT = 704
   DEFAULT CHARSET = utf8mb4 COMMENT ='Task instance';
 
+-- ----------------------------
+-- Table structure for cluster_set
+-- ----------------------------
+DROP TABLE IF EXISTS `cluster_set`;
+CREATE TABLE `cluster_set`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `set_name`                varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `cn_name`             varchar(256)          DEFAULT NULL COMMENT 'Chinese display name',
+    `description`         varchar(256)          DEFAULT NULL COMMENT 'ClusterSet Introduction',
+    `middleware_type`     varchar(10)           DEFAULT 'Pulsar' COMMENT 'The middleware type of data storage, high throughput: Pulsar',
+    `in_charges`          varchar(512)          DEFAULT NULL COMMENT 'Name of responsible person, separated by commas',
+    `followers`           varchar(512)          DEFAULT NULL COMMENT 'List of names of business followers, separated by commas',
+    `status`              int(11)               DEFAULT '21' COMMENT 'ClusterSet status',
+    `is_deleted`          tinyint(1)            DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, 1: deleted',
+    `creator`             varchar(64)           DEFAULT NULL COMMENT 'creator name',
+    `modifier`            varchar(64)           DEFAULT NULL COMMENT 'modifier name',
+    `create_time`         timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'create time',
+    `modify_time`         timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_cluster_set` (`set_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='ClusterSet table';
+
+-- ----------------------------
+-- Table structure for cluster_set_inlongid
+-- ----------------------------
+DROP TABLE IF EXISTS `cluster_set_inlongid`;
+CREATE TABLE `cluster_set_inlongid`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `set_name`                varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `business_identifier` varchar(128) NOT NULL COMMENT 'Business identifier, filled in by the user, undeleted ones cannot be repeated',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_cluster_set_inlongid` (`set_name`,`business_identifier`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='InlongId table';
+
+-- ----------------------------
+-- Table structure for cache_cluster
+-- ----------------------------
+DROP TABLE IF EXISTS `cache_cluster`;
+CREATE TABLE `cache_cluster`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `cluster_name`        varchar(128) NOT NULL COMMENT 'CacheCluster name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `zone`                varchar(128) NOT NULL COMMENT 'Zone, sz/sh/tj',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_cache_cluster` (`cluster_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='CacheCluster table';
+
+-- ----------------------------
+-- Table structure for cache_cluster_ext
+-- ----------------------------
+DROP TABLE IF EXISTS `cache_cluster_ext`;
+CREATE TABLE `cache_cluster_ext`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `cluster_name`        varchar(128) NOT NULL COMMENT 'CacheCluster name, English, numbers and underscore',
+    `key_name`            varchar(64)  NOT NULL COMMENT 'Configuration item name',
+    `key_value`           varchar(256)          DEFAULT NULL COMMENT 'The value of the configuration item',
+    `is_deleted`          tinyint(1)            DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, 1: deleted',
+    `modify_time`         timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time',
+    PRIMARY KEY (`id`),
+    KEY `index_cache_cluster` (`cluster_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='CacheCluster extension table';
+
+-- ----------------------------
+-- Table structure for cache_topic
+-- ----------------------------
+DROP TABLE IF EXISTS `cache_topic`;
+CREATE TABLE `cache_topic`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `topic_name`          varchar(128) NOT NULL COMMENT 'Topic name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `partition_num`       int(11) NOT NULL COMMENT 'Partition number',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_cache_topic` (`topic_name`,`set_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='CacheTopic table';
+
+-- ----------------------------
+-- Table structure for proxy_cluster
+-- ----------------------------
+DROP TABLE IF EXISTS `proxy_cluster`;
+CREATE TABLE `proxy_cluster`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `cluster_name`        varchar(128) NOT NULL COMMENT 'ProxyCluster name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `zone`                varchar(128) NOT NULL COMMENT 'Zone, sz/sh/tj',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_proxy_cluster` (`cluster_name`,`set_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='ProxyCluster table';
+
+-- ----------------------------
+-- Table structure for proxy_cluster_to_cache_cluster
+-- ----------------------------
+DROP TABLE IF EXISTS `proxy_cluster_to_cache_cluster`;
+CREATE TABLE `proxy_cluster_to_cache_cluster`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `proxy_cluster_name`  varchar(128) NOT NULL COMMENT 'ProxyCluster name, English, numbers and underscore',
+    `cache_cluster_name`  varchar(128)  NOT NULL COMMENT 'CacheCluster name, English, numbers and underscore',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_proxy_cluster_to_cache_cluster` (`proxy_cluster_name`,`cache_cluster_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='The relation table of ProxyCluster and CacheCluster';
+
+-- ----------------------------
+-- Table structure for flume_source
+-- ----------------------------
+DROP TABLE IF EXISTS `flume_source`;
+CREATE TABLE `flume_source`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `source_name`         varchar(128) NOT NULL COMMENT 'FlumeSource name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `type`                varchar(128)  NOT NULL COMMENT 'FlumeSource classname',
+    `channels`            varchar(128)  NOT NULL COMMENT 'The channels of FlumeSource, separated by space',
+    `selector_type`       varchar(128)  NOT NULL COMMENT 'FlumeSource channel selector classname',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_flume_source` (`source_name`,`set_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='FlumeSource table';
+
+-- ----------------------------
+-- Table structure for flume_source_ext
+-- ----------------------------
+DROP TABLE IF EXISTS `flume_source_ext`;
+CREATE TABLE `flume_source_ext`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `parent_name`         varchar(128) NOT NULL COMMENT 'FlumeSource name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `key_name`            varchar(64)  NOT NULL COMMENT 'Configuration item name',
+    `key_value`           varchar(256)          DEFAULT NULL COMMENT 'The value of the configuration item',
+    `is_deleted`          tinyint(1)            DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, 1: deleted',
+    `modify_time`         timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time',
+    PRIMARY KEY (`id`),
+    KEY `index_flume_source_ext` (`parent_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='FlumeSource extension table';
+
+-- ----------------------------
+-- Table structure for flume_channel
+-- ----------------------------
+DROP TABLE IF EXISTS `flume_channel`;
+CREATE TABLE `flume_channel`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `channel_name`        varchar(128) NOT NULL COMMENT 'FlumeChannel name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `type`                varchar(128)  NOT NULL COMMENT 'FlumeChannel classname',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_flume_channel` (`channel_name`,`set_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='FlumeChannel table';
+
+-- ----------------------------
+-- Table structure for flume_channel_ext
+-- ----------------------------
+DROP TABLE IF EXISTS `flume_channel_ext`;
+CREATE TABLE `flume_channel_ext`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `parent_name`        varchar(128) NOT NULL COMMENT 'FlumeChannel name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `key_name`            varchar(64)  NOT NULL COMMENT 'Configuration item name',
+    `key_value`           varchar(256)          DEFAULT NULL COMMENT 'The value of the configuration item',
+    `is_deleted`          tinyint(1)            DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, 1: deleted',
+    `modify_time`         timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time',
+    PRIMARY KEY (`id`),
+    KEY `index_flume_channel_ext` (`parent_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='FlumeChannel extension table';
+
+-- ----------------------------
+-- Table structure for flume_sink
+-- ----------------------------
+DROP TABLE IF EXISTS `flume_sink`;
+CREATE TABLE `flume_sink`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `sink_name`           varchar(128) NOT NULL COMMENT 'FlumeSink name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `type`                varchar(128)  NOT NULL COMMENT 'FlumeSink classname',
+    `channel`             varchar(128)  NOT NULL COMMENT 'FlumeSink channel',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_flume_sink` (`sink_name`,`set_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='FlumeSink table';
+
+-- ----------------------------
+-- Table structure for flume_sink_ext
+-- ----------------------------
+DROP TABLE IF EXISTS `flume_sink_ext`;
+CREATE TABLE `flume_sink_ext`
+(
+    `id`                  int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `parent_name`        varchar(128) NOT NULL COMMENT 'FlumeSink name, English, numbers and underscore',
+    `set_name`            varchar(128) NOT NULL COMMENT 'ClusterSet name, English, numbers and underscore',
+    `key_name`            varchar(64)  NOT NULL COMMENT 'Configuration item name',
+    `key_value`           varchar(256)          DEFAULT NULL COMMENT 'The value of the configuration item',
+    `is_deleted`          tinyint(1)            DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, 1: deleted',
+    `modify_time`         timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time',
+    PRIMARY KEY (`id`),
+    KEY `index_flume_sink_ext` (`parent_name`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='FlumeSink extension table';
+
 SET FOREIGN_KEY_CHECKS = 1;
