@@ -92,9 +92,9 @@ public class FlowCtrlRuleHandler {
      * @param flowCtrlInfo
      * @throws Exception
      */
-    public void updateDefFlowCtrlInfo(final int qyrPriorityId,
-                                      final long flowCtrlId,
-                                      final String flowCtrlInfo) throws Exception {
+    public void updateFlowCtrlInfo(final int qyrPriorityId,
+                                   final long flowCtrlId,
+                                   final String flowCtrlInfo) throws Exception {
         if (flowCtrlId == this.flowCtrlId.get()) {
             return;
         }
@@ -158,7 +158,6 @@ public class FlowCtrlRuleHandler {
         return null;
     }
 
-
     public int getNormFreqInMs() {
         return this.filterCtrlItem.getFreqLtInMs();
     }
@@ -287,7 +286,6 @@ public class FlowCtrlRuleHandler {
         return qryPriorityId.get();
     }
 
-
     /**
      * @param qryPriorityId
      */
@@ -311,7 +309,6 @@ public class FlowCtrlRuleHandler {
         }
     }
 
-
     /**
      * Parse FlowCtrlInfo value
      * @param flowCtrlInfo flowCtrlInfo json value
