@@ -99,7 +99,6 @@ public class TubeBroker implements Stoppable {
     private AtomicLong heartbeatErrors = new AtomicLong(0);
     private int maxReleaseTryCnt = 10;
 
-
     public TubeBroker(final BrokerConfig tubeConfig) throws Exception {
         java.security.Security.setProperty("networkaddress.cache.ttl", "3");
         java.security.Security.setProperty("networkaddress.cache.negative.ttl", "1");
@@ -314,7 +313,7 @@ public class TubeBroker implements Stoppable {
                 flowCheckId = response.getFlowCheckId();
                 try {
                     flowCtrlRuleHandler
-                            .updateDefFlowCtrlInfo(qryPriorityId,
+                            .updateFlowCtrlInfo(qryPriorityId,
                                     flowCheckId, response.getFlowControlInfo());
                 } catch (Exception e1) {
                     logger.warn(
@@ -416,7 +415,6 @@ public class TubeBroker implements Stoppable {
         }
     }
 
-
     private void procConfigFromRegister(StringBuilder sBuilder,
                                         final RegisterResponseM2B response) {
         // process service status
@@ -432,7 +430,7 @@ public class TubeBroker implements Stoppable {
             if (response.getFlowCheckId() != flowCtrlRuleHandler.getFlowCtrlId()) {
                 try {
                     flowCtrlRuleHandler
-                            .updateDefFlowCtrlInfo(response.getQryPriorityId(),
+                            .updateFlowCtrlInfo(response.getQryPriorityId(),
                                     response.getFlowCheckId(), response.getFlowControlInfo());
                 } catch (Exception e1) {
                     logger.warn("[Register response] found parse flowCtrl rules failure", e1);
